@@ -26,22 +26,14 @@ import org.glom.web.client.StringUtils;
 import com.google.gwt.place.shared.PlaceTokenizer;
 import com.google.gwt.place.shared.Prefix;
 
-public class ListPlace extends HasSelectableTablePlace {
-
-	private final String quickFind;
+public class ListPlace extends HasRecordsPlace {
 
 	public ListPlace(final String documentID, final String tableName, final String quickFind) {
-		super(documentID, tableName);
-		this.quickFind = quickFind;
-	}
-
-	public String getQuickFind() {
-		return quickFind;
+		super(documentID, tableName, quickFind);
 	}
 
 	@Prefix("list")
-	public static class Tokenizer extends HasSelectableTablePlace.Tokenizer implements PlaceTokenizer<ListPlace> {
-		protected final String quickFindKey = "quickfind";
+	public static class Tokenizer extends HasRecordsPlace.Tokenizer implements PlaceTokenizer<ListPlace> {
 
 		@Override
 		public String getToken(final ListPlace place) {
