@@ -19,12 +19,12 @@
 
 package org.glom.web.client.ui;
 
-import org.glom.web.shared.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
 
 /**
  *
  */
 public interface ListView extends View {
 
-	public void setCellTable(final String documentID, LayoutGroup layoutGroup, String quickFind);
+	public void setCellTable(final String documentID, final String tableName, LayoutGroup layoutGroup, String quickFind);
 }
