@@ -22,11 +22,11 @@ package org.glom.web.client.ui.details;
 import java.util.ArrayList;
 
 import org.glom.web.client.StringUtils;
-import org.glom.web.shared.layout.LayoutGroup;
-import org.glom.web.shared.layout.LayoutItem;
-import org.glom.web.shared.layout.LayoutItemField;
-import org.glom.web.shared.layout.LayoutItemNotebook;
-import org.glom.web.shared.layout.LayoutItemPortal;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutItem;
+import org.glom.web.shared.libglom.layout.LayoutItemField;
+import org.glom.web.shared.libglom.layout.LayoutItemNotebook;
+import org.glom.web.shared.libglom.layout.LayoutItemPortal;
 
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.FlowPanel;
