@@ -27,7 +27,7 @@ import org.glom.web.client.ui.cell.NavigationButtonCell;
 import org.glom.web.client.ui.list.ListTable;
 import org.glom.web.shared.DataItem;
 import org.glom.web.shared.TypedDataItem;
-import org.glom.web.shared.layout.LayoutItemPortal;
+import org.glom.web.shared.libglom.layout.LayoutItemPortal;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.dom.client.Document;
@@ -61,22 +61,23 @@ public class RelatedListTable extends ListTable {
 	private static final int MIN_TABLE_ROWS = MAX_TABLE_ROWS;
 
 	private TypedDataItem foreignKeyValue;
-	private String relationshipName;
+	private LayoutItemPortal portal = null;
 	private int numNonEmptyRows = 0;
 
 	private final static int expectedHeight = initializeExepectedHeight();
 
-	public RelatedListTable(String documentID, LayoutItemPortal layoutItemPortal, TypedDataItem foreignKeyValue,
+	public RelatedListTable(String documentID, String tableName, LayoutItemPortal layoutItemPortal, TypedDataItem foreignKeyValue,
 			NavigationButtonCell navigationButtonCell) {
 
 		super(documentID);
+		super.tableName = tableName;
 
 		// These variables need to be set before the createCellTable() method is called so that the data provider can
 		// use them.
 		this.foreignKeyValue = foreignKeyValue;
-		this.relationshipName = layoutItemPortal.getName();
+		this.portal = layoutItemPortal;
 
-		createCellTable(layoutItemPortal, MAX_TABLE_ROWS, constants.open(), navigationButtonCell);
+		createCellTable(layoutItemPortal, tableName, MAX_TABLE_ROWS, constants.open(), navigationButtonCell);
 
 		// The FixedLayout property tells the browser that we want to manually specify the column widths and don't want
 		// the table to overflow it's container. Browsers will make columns with equal widths since we're currently not
@@ -104,13 +105,18 @@ public class RelatedListTable extends ListTable {
 					@Override
 					public void onFailure(Throwable caught) {
 						// TODO: create a way to notify users of asynchronous callback failures
-						GWT.log("AsyncCallback Failed: OnlineGlomService.get(Sorted)RelatedListData()");
+						GWT.log("AsyncCallback Failed: OnlineGlomService.get(Sorted)RelatedListData(): "
+								+ caught.getMessage());
 					}
 
 					@Override
 					public void onSuccess(ArrayList<DataItem[]> result) {
 						// keep track of the number of non-empty rows (rows with data)
-						numNonEmptyRows = result.size();
+						numNonEmptyRows = 0;
+						if(result != null) {
+							numNonEmptyRows = result.size();
+						}
+
 						// Add empty rows if required.
 						int numEmptyRows = MIN_TABLE_ROWS - numNonEmptyRows;
 						for (int i = 0; i < numEmptyRows; i++) {
@@ -133,13 +139,13 @@ public class RelatedListTable extends ListTable {
 					ColumnSortInfo info = colSortList.get(0);
 
 					OnlineGlomServiceAsync.Util.getInstance().getSortedRelatedListData(documentID, tableName,
-							relationshipName, foreignKeyValue, start, range.getLength(),
+							portal, foreignKeyValue, start, range.getLength(),
 							cellTable.getColumnIndex((Column<DataItem[], ?>) info.getColumn()), info.isAscending(),
 							callback);
 
 				} else {
 					OnlineGlomServiceAsync.Util.getInstance().getRelatedListData(documentID, tableName,
-							relationshipName, foreignKeyValue, start, range.getLength(), callback);
+							portal, foreignKeyValue, start, range.getLength(), callback);
 
 				}
 
