@@ -25,7 +25,7 @@ import org.glom.web.client.OnlineGlomServiceAsync;
 import org.glom.web.client.ui.OnlineGlomConstants;
 import org.glom.web.client.ui.cell.NavigationButtonCell;
 import org.glom.web.shared.DataItem;
-import org.glom.web.shared.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.user.cellview.client.Column;
@@ -53,11 +53,13 @@ public class ListViewTable extends ListTable {
 
 	private int numNonEmptyRows = 0;
 
-	public ListViewTable(final String documentID, final LayoutGroup layoutGroup,
+	public ListViewTable(final String documentID, String tableName, final LayoutGroup layoutGroup,
 			final NavigationButtonCell navigationButtonCell, final String quickFind) {
 		super(documentID);
+		this.tableName = tableName;
 		this.quickFind = quickFind;
-		createCellTable(layoutGroup, MAX_TABLE_ROWS, constants.details(), navigationButtonCell);
+		// TODO: Is tableName set here?
+		createCellTable(layoutGroup, tableName, MAX_TABLE_ROWS, constants.details(), navigationButtonCell);
 	}
 
 	/*
@@ -79,7 +81,8 @@ public class ListViewTable extends ListTable {
 					@Override
 					public void onFailure(final Throwable caught) {
 						// TODO: create a way to notify users of asynchronous callback failures
-						GWT.log("AsyncCallback Failed: OnlineGlomService.get(Sorted)ListViewData()");
+						GWT.log("AsyncCallback Failed: OnlineGlomService.get(Sorted)ListViewData(): "
+								+ caught.getMessage());
 					}
 
 					@Override
