@@ -20,23 +20,21 @@
 package org.glom.web.server.database;
 
 import java.util.ArrayList;
+import java.util.List;
 
-import org.apache.commons.lang.StringUtils;
-import org.glom.libglom.Document;
-import org.glom.libglom.Field;
-import org.glom.libglom.FieldVector;
-import org.glom.libglom.Glom;
-import org.glom.libglom.LayoutGroupVector;
-import org.glom.libglom.LayoutItem_Portal;
-import org.glom.libglom.Relationship;
-import org.glom.libglom.SortClause;
-import org.glom.libglom.SqlBuilder;
-import org.glom.libglom.SqlExpr;
-import org.glom.libglom.Value;
+import org.apache.commons.lang3.StringUtils;
 import org.glom.web.server.Log;
-import org.glom.web.server.Utils;
+import org.glom.web.server.SqlUtils;
+import org.glom.web.server.libglom.Document;
 import org.glom.web.shared.DataItem;
 import org.glom.web.shared.TypedDataItem;
+import org.glom.web.shared.libglom.Field;
+import org.glom.web.shared.libglom.Relationship;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutItemField;
+import org.glom.web.shared.libglom.layout.LayoutItemPortal;
+import org.glom.web.shared.libglom.layout.SortClause;
+import org.jooq.Condition;
 
 import com.mchange.v2.c3p0.ComboPooledDataSource;
 
@@ -45,29 +43,28 @@ import com.mchange.v2.c3p0.ComboPooledDataSource;
  */
 public class RelatedListDBAccess extends ListDBAccess {
 	private TypedDataItem foreignKeyValue = null;
-	private LayoutItem_Portal portal = null;
+	private LayoutItemPortal portal = null;
 	private String parentTable = null;
 	private String whereClauseToTableName = null;
 	private Field whereClauseToKeyField = null;
 
 	public RelatedListDBAccess(final Document document, final String documentID, final ComboPooledDataSource cpds,
-			final String tableName, final String relationshipName) {
+			final String tableName, final LayoutItemPortal portal) {
 		super(document, documentID, cpds, tableName);
 
-		final LayoutItem_Portal portal = getPortal(relationshipName);
 		if (portal == null) {
-			Log.error(documentID, tableName, "Couldn't find LayoutItem_Portal \"" + relationshipName + "\" in table \""
-					+ tableName + "\". " + "Cannot retrive data for the related list.");
+			Log.error(documentID, tableName, "portal is null in table \""
+					+ tableName + "\". " + "Cannot retrieve data for the related list.");
 			return;
 		}
 
 		parentTable = tableName;
 		// Reassign the tableName variable to table that is being used for the related list. This needs to be set before
 		// getFieldsToShowForSQLQuery().
-		this.tableName = portal.get_table_used("" /* parent table - not relevant */);
+		this.tableName = portal.getTableUsed("" /* parent table - not relevant */);
 
-		// Convert the libglom LayoutGroup object into a LayoutFieldVector suitable for SQL queries.
-		final LayoutGroupVector tempLayoutGroupVec = new LayoutGroupVector();
+		// Convert the libglom LayoutGroup object into a List<LayoutItem_Field> suitable for SQL queries.
+		final List<LayoutGroup> tempLayoutGroupVec = new ArrayList<LayoutGroup>();
 		tempLayoutGroupVec.add(portal);
 		fieldsToGet = getFieldsToShowForSQLQuery(tempLayoutGroupVec);
 
@@ -75,21 +72,26 @@ public class RelatedListDBAccess extends ListDBAccess {
 		 * The code from the rest of this method was inspired by code from Glom:
 		 * Base_DB::set_found_set_where_clause_for_portal()
 		 */
-		final Relationship relationship = portal.get_relationship();
+		final Relationship relationship = portal.getRelationship();
 
 		// Notice that, in the case that this is a portal to doubly-related records,
 		// The WHERE clause mentions the first-related table (though by the alias defined in extra_join)
 		// and we add an extra JOIN to mention the second-related table.
 
-		whereClauseToTableName = relationship.get_to_table();
-		whereClauseToKeyField = getFieldInTable(relationship.get_to_field(), whereClauseToTableName);
+		whereClauseToTableName = relationship.getToTable();
+		whereClauseToKeyField = getFieldInTable(relationship.getToField(), whereClauseToTableName);
 
 		// Add primary key
-		fieldsToGet.add(getPrimaryKeyLayoutItemField(this.tableName));
+		final LayoutItemField primaryKey = getPrimaryKeyLayoutItemField(this.tableName);
+		if(primaryKey == null) {
+			Log.error(documentID, tableName, "RelatedListDBAccess: getPrimaryKeyLayoutItemField() failed.");
+		} else {
+			fieldsToGet.add(primaryKey);
+		}
 
-		final Relationship relationshipRelated = portal.get_related_relationship();
+		final Relationship relationshipRelated = portal.getRelatedRelationship();
 		if (relationshipRelated != null) {
-			Log.error(documentID, tableName, "The related relationship " + relationshipRelated.get_name()
+			Log.error(documentID, tableName, "The related relationship " + relationshipRelated.getName()
 					+ " is not empty but the related relationship code has not been implemented yet.");
 
 			// FIXME port this Glom code to Java
@@ -166,20 +168,15 @@ public class RelatedListDBAccess extends ListDBAccess {
 			return "";
 		}
 
-		SqlExpr whereClause = new SqlExpr(); // Note that we ignore quickFind.
+		Condition whereClause = null; // Note that we ignore quickFind.
 		// only attempt to make a where clause if it makes sense to do so
 		if (!StringUtils.isEmpty(whereClauseToTableName)) {
-			final Value gdaForeignKeyValue = Utils.getGlomTypeGdaValueForTypedDataItem(documentID, tableName,
-					whereClauseToKeyField.get_glom_type(), foreignKeyValue);
-			if (gdaForeignKeyValue != null)
-				whereClause = Glom.build_simple_where_expression(whereClauseToTableName, whereClauseToKeyField,
-						gdaForeignKeyValue);
+			if (foreignKeyValue != null)
+				whereClause = SqlUtils.buildSimpleWhereExpression(whereClauseToTableName, whereClauseToKeyField,
+						foreignKeyValue);
 		}
 
-		final Relationship extraJoin = new Relationship(); // Ignored.
-		final SqlBuilder builder = Glom.build_sql_select_with_where_clause(tableName, fieldsToGet, whereClause,
-				extraJoin, sortClause);
-		return Glom.sqlbuilder_get_full_query(builder);
+		return SqlUtils.buildSqlSelectWithWhereClause(tableName, fieldsToGet, whereClause, sortClause);
 
 	}
 
@@ -188,10 +185,10 @@ public class RelatedListDBAccess extends ListDBAccess {
 		if (StringUtils.isEmpty(tableName))
 			return null;
 
-		final FieldVector fields = document.get_table_fields(tableName);
+		final List<Field> fields = document.getTableFields(tableName);
 		for (int i = 0; i < fields.size(); i++) {
 			final Field field = fields.get(i);
-			if (fieldName.equals(field.get_name())) {
+			if (fieldName.equals(field.getName())) {
 				return field;
 			}
 		}
@@ -219,20 +216,15 @@ public class RelatedListDBAccess extends ListDBAccess {
 			return "";
 		}
 
-		SqlExpr whereClause = new SqlExpr();
+		Condition whereClause = null;
 		// only attempt to make a where clause if it makes sense to do so
 		if (!whereClauseToTableName.isEmpty() && whereClauseToKeyField != null) {
-			final Value gdaForeignKeyValue = Utils.getGlomTypeGdaValueForTypedDataItem(documentID, tableName,
-					whereClauseToKeyField.get_glom_type(), foreignKeyValue);
-			if (gdaForeignKeyValue != null)
-				whereClause = Glom.build_simple_where_expression(whereClauseToTableName, whereClauseToKeyField,
-						gdaForeignKeyValue);
+			if (foreignKeyValue != null)
+				whereClause = SqlUtils.buildSimpleWhereExpression(whereClauseToTableName, whereClauseToKeyField,
+						foreignKeyValue);
 		}
 
-		final SqlBuilder builder = Glom.build_sql_select_with_where_clause(tableName, fieldsToGet, whereClause);
-		final SqlBuilder countBuilder = Glom.build_sql_select_count_rows(builder);
-		return Glom.sqlbuilder_get_full_query(countBuilder);
-
+		return SqlUtils.buildSqlCountSelectWithWhereClause(tableName, fieldsToGet, whereClause);
 	}
 
 }
