@@ -24,21 +24,20 @@ import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.util.ArrayList;
+import java.util.List;
 
-import org.apache.commons.lang.StringUtils;
-import org.glom.libglom.Document;
-import org.glom.libglom.Field;
-import org.glom.libglom.Field.glom_field_type;
-import org.glom.libglom.Glom;
-import org.glom.libglom.LayoutFieldVector;
-import org.glom.libglom.LayoutItem_Field;
-import org.glom.libglom.LayoutItem_Portal;
-import org.glom.libglom.SqlBuilder;
-import org.glom.libglom.Value;
+import org.apache.commons.lang3.StringUtils;
 import org.glom.web.server.Log;
-import org.glom.web.server.Utils;
+import org.glom.web.server.SqlUtils;
+import org.glom.web.server.libglom.Document;
 import org.glom.web.shared.NavigationRecord;
 import org.glom.web.shared.TypedDataItem;
+import org.glom.web.shared.libglom.Field;
+import org.glom.web.shared.libglom.Field.GlomFieldType;
+import org.glom.web.shared.libglom.layout.LayoutItemField;
+import org.glom.web.shared.libglom.layout.LayoutItemPortal;
+import org.glom.web.shared.libglom.layout.TableToViewDetails;
 
 import com.mchange.v2.c3p0.ComboPooledDataSource;
 
@@ -47,16 +46,15 @@ import com.mchange.v2.c3p0.ComboPooledDataSource;
  */
 public class RelatedListNavigation extends DBAccess {
 
-	private LayoutItem_Portal portal;
+	private LayoutItemPortal portal;
 
-	public RelatedListNavigation(Document document, String documentID, ComboPooledDataSource cpds, String tableName,
-			String relationshipName) {
+	public RelatedListNavigation(final Document document, final String documentID, final ComboPooledDataSource cpds,
+			final String tableName, final LayoutItemPortal portal) {
 		super(document, documentID, cpds, tableName);
 
-		LayoutItem_Portal portal = getPortal(relationshipName);
 		if (portal == null) {
-			Log.error(documentID, tableName, "Couldn't find LayoutItem_Portal \"" + relationshipName + "\" in table \""
-					+ tableName + "\". " + "Cannot retrive data for the related list.");
+			Log.error(documentID, tableName, "portal is null in table \""
+					+ tableName + "\". " + "Cannot retrieve data for the related list.");
 			return;
 		}
 
@@ -68,40 +66,57 @@ public class RelatedListNavigation extends DBAccess {
 	 * 
 	 * This code was ported from Glom: Box_Data_Portal::get_suitable_record_to_view_details()
 	 */
-	public NavigationRecord getNavigationRecord(TypedDataItem primaryKeyValue) {
+	public NavigationRecord getNavigationRecord(final TypedDataItem primaryKeyValue) {
 
 		if (portal == null) {
 			Log.error(documentID, tableName,
-					"The related list navigation cannot be determined because the LayoutItem_Portal has not been found.");
+					"The related list navigation cannot be determined because the LayoutItemPortal has not been found.");
+			return null;
+		}
+		
+		if (primaryKeyValue == null) {
+			Log.error(documentID, tableName,
+					"The related list navigation cannot be determined because the primaryKeyValue is null.");
 			return null;
 		}
 
-		StringBuffer navigationTableNameSB = new StringBuffer();
-		LayoutItem_Field navigationRelationshipItem = new LayoutItem_Field();
-		portal.get_suitable_table_to_view_details(navigationTableNameSB, navigationRelationshipItem, document);
-
-		String navigationTableName = navigationTableNameSB.toString();
-		if (StringUtils.isEmpty(navigationTableName)) {
+		//TODO: For some reason, LayoutItemPortal.navigationTable is null after using deepCopy(),
+		//so we can't use our cache:
+		//final TableToViewDetails navigationTable = portal.getNavigationTable();
+		final TableToViewDetails navigationTable = document.getPortalSuitableTableToViewDetails(portal);
+		if (navigationTable == null) {
+			Log.error(documentID, tableName,
+					"The related list navigation cannot cannot be determined because the navigation table details are empty.");
+			return null;
+		}
+		
+		if (StringUtils.isEmpty(navigationTable.tableName)) {
 			Log.error(documentID, tableName,
 					"The related list navigation cannot cannot be determined because the navigation table name is empty.");
 			return null;
 		}
 
 		// Get the primary key of that table:
-		Field navigationTablePrimaryKey = getPrimaryKeyField(navigationTableName);
+		final Field navigationTablePrimaryKey = getPrimaryKeyField(navigationTable.tableName);
 
 		// Build a layout item to get the field's value:
-		navigationRelationshipItem.set_full_field_details(navigationTablePrimaryKey);
+		final LayoutItemField navigationRelationshipItem = new LayoutItemField();
+		navigationRelationshipItem.setName(navigationTablePrimaryKey.getName());
+		navigationRelationshipItem.setFullFieldDetails(navigationTablePrimaryKey);
+		if(navigationTable.usesRelationship != null) {
+			navigationRelationshipItem.setRelationship(navigationTable.usesRelationship.getRelationship());
+			navigationRelationshipItem.setRelatedRelationship(navigationTable.usesRelationship.getRelatedRelationship());
+		}
 
 		// Get the value of the navigation related primary key:
-		LayoutFieldVector fieldsToGet = new LayoutFieldVector();
+		final List<LayoutItemField> fieldsToGet = new ArrayList<LayoutItemField>();
 		fieldsToGet.add(navigationRelationshipItem);
 
 		// For instance "invoice_line_id" if this is a portal to an "invoice_lines" table:
-		String relatedTableName = portal.get_table_used("" /* not relevant */);
-		Field primaryKeyField = getPrimaryKeyField(relatedTableName);
+		final String relatedTableName = portal.getTableUsed("" /* not relevant */);
+		final Field primaryKeyField = getPrimaryKeyField(relatedTableName);
 
-		NavigationRecord navigationRecord = new NavigationRecord();
+		final NavigationRecord navigationRecord = new NavigationRecord();
 		String query = null;
 		Connection conn = null;
 		Statement st = null;
@@ -111,31 +126,26 @@ public class RelatedListNavigation extends DBAccess {
 			conn = cpds.getConnection();
 			st = conn.createStatement(ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_READ_ONLY);
 
-			Value gdaPrimaryKeyValue = Utils.getGlomTypeGdaValueForTypedDataItem(documentID, tableName,
-					primaryKeyField.get_glom_type(), primaryKeyValue);
+			if (primaryKeyValue != null) {
 
-			// Only create the query if we've created a Gda Value from the DataItem.
-			if (gdaPrimaryKeyValue != null) {
-
-				SqlBuilder builder = Glom.build_sql_select_with_key(relatedTableName, fieldsToGet, primaryKeyField,
-						gdaPrimaryKeyValue);
-				query = Glom.sqlbuilder_get_full_query(builder);
+				query = SqlUtils.buildSqlSelectWithKey(relatedTableName, fieldsToGet, primaryKeyField,
+						primaryKeyValue);
 
 				rs = st.executeQuery(query);
 
 				// Set the output parameters:
-				navigationRecord.setTableName(navigationTableName);
+				navigationRecord.setTableName(navigationTable.tableName);
 
 				rs.next();
-				TypedDataItem navigationTablePrimaryKeyValue = new TypedDataItem();
-				ResultSetMetaData rsMetaData = rs.getMetaData();
-				int queryReturnValueType = rsMetaData.getColumnType(1);
-				switch (navigationTablePrimaryKey.get_glom_type()) {
+				final TypedDataItem navigationTablePrimaryKeyValue = new TypedDataItem();
+				final ResultSetMetaData rsMetaData = rs.getMetaData();
+				final int queryReturnValueType = rsMetaData.getColumnType(1);
+				switch (navigationTablePrimaryKey.getGlomType()) {
 				case TYPE_NUMERIC:
 					if (queryReturnValueType == java.sql.Types.NUMERIC) {
 						navigationTablePrimaryKeyValue.setNumber(rs.getDouble(1));
 					} else {
-						logNavigationTablePrimaryKeyTypeMismatchError(Field.glom_field_type.TYPE_NUMERIC,
+						logNavigationTablePrimaryKeyTypeMismatchError(Field.GlomFieldType.TYPE_NUMERIC,
 								rsMetaData.getColumnTypeName(1));
 					}
 					break;
@@ -143,7 +153,7 @@ public class RelatedListNavigation extends DBAccess {
 					if (queryReturnValueType == java.sql.Types.VARCHAR) {
 						navigationTablePrimaryKeyValue.setText(rs.getString(1));
 					} else {
-						logNavigationTablePrimaryKeyTypeMismatchError(Field.glom_field_type.TYPE_TEXT,
+						logNavigationTablePrimaryKeyTypeMismatchError(Field.GlomFieldType.TYPE_TEXT,
 								rsMetaData.getColumnTypeName(1));
 					}
 					break;
@@ -159,13 +169,13 @@ public class RelatedListNavigation extends DBAccess {
 				// products table.
 				if (navigationTablePrimaryKeyValue.isEmpty()) {
 					Log.info(documentID, tableName, "SQL query returned empty primary key for navigation to the "
-							+ navigationTableName + "table. Navigation may not work correctly");
+							+ navigationTable.tableName + "table. Navigation may not work correctly");
 					navigationRecord.setPrimaryKeyValue(null);
 				} else {
 					navigationRecord.setPrimaryKeyValue(navigationTablePrimaryKeyValue);
 				}
 			}
-		} catch (SQLException e) {
+		} catch (final SQLException e) {
 			Log.error(documentID, tableName, "Error executing database query: " + query, e);
 			// TODO: somehow notify user of problem
 			return null;
@@ -178,7 +188,7 @@ public class RelatedListNavigation extends DBAccess {
 					st.close();
 				if (conn != null)
 					conn.close();
-			} catch (Exception e) {
+			} catch (final Exception e) {
 				Log.error(documentID, tableName,
 						"Error closing database resources. Subsequent database queries may not work.", e);
 			}
@@ -187,7 +197,8 @@ public class RelatedListNavigation extends DBAccess {
 		return navigationRecord;
 	}
 
-	private void logNavigationTablePrimaryKeyTypeMismatchError(glom_field_type glomType, String queryReturnValueTypeName) {
+	private void logNavigationTablePrimaryKeyTypeMismatchError(final GlomFieldType glomType,
+			final String queryReturnValueTypeName) {
 		Log.error(documentID, tableName, "The expected type from the Glom document: " + glomType
 				+ " doesn't match the type returned by the SQL query: " + queryReturnValueTypeName + ".");
 		Log.error(documentID, tableName, "The navigation table primary key value will not be created. This is a bug.");
